Ext.namespace("dSS", "dSS.config", "dSS.devprops");

// form *must* react to the submit event and fire a formsubmitted
// event in response; it *must* also fire a formloaded event once all d
// has been received
//
// parameters: dsid
dSS.devprops.OutputModeForm = Ext.extend(Ext.form.FormPanel, {
    constructor: function(config) {
        if (config.dsid === undefined) {
            Ext.MessageBox.alert(dSS._("Error"), ("Missing dSID"));
            return;
        }

        this.dsid = config.dsid;

        this.addEvents('formsubmitted', 'formloaded');

        Ext.apply(this, {
            bubbleEvents: [ 'formsubmitted', 'formloaded' ],
            padding: 5,
            scope: this,
            params: { 'class' : 3, index : 0, dsid : config.dsid },
            items:
            [
                {
                    xtype: 'radiogroup',
                    ref: 'radio',
                    fieldLabel: dSS._("Output mode"),
                    columns: 1,
                    items:
                    [
                        {
                            boxLabel: dSS._("switched"),
                            name: 'rb_outmode_' + config.dsid,
                            id: dSS.config.deviceParams.OUTPUT_MODE_SWITCH.toString(),
                            inputValue : dSS.config.deviceParams.OUTPUT_MODE_SWITCH
                        },
                        {
                            boxLabel: dSS._("dimmed"),
                            name: 'rb_outmode_' + config.dsid,
                            id: dSS.config.deviceParams.OUTPUT_MODE_DIMMER.toString(),
                            inputValue : dSS.config.deviceParams.OUTPUT_MODE_DIMMER
                        },
                        {
                            boxLabel: dSS._("disabled"),
                            name: 'rb_outmode_' + config.dsid,
                            id: dSS.config.deviceParams.OUTPUT_MODE_DISABLED.toString(),
                            inputValue : dSS.config.deviceParams.OUTPUT_MODE_DISABLED
                        }
                    ]
                }
            ]
        });

        dSS.devprops.OutputModeForm.superclass.constructor.apply(this, arguments);

        this.on('dataloaded', function(data) {
                if (this.closed === true) {
                    return;
                }

                if (data.loader !== dSS.devprops.Loaders.COMBINED_PB_OUTMODE) {
                    return;
                }

                if (data.json.ok !== true) {
                    this.radio.markInvalid(data.json.message);
                    this.fireEvent('formloaded', true);
                    return;
                }

                var val = data.json.result[this.dsid][0].outputMode;
                this.radio.setValue(val, val);
                this.loadedValue = val;
                this.el.unmask();
                this.fireEvent('formloaded', true);
            },
            this);

        this.on('beforedestroy', function() {
                this.closed = true;
            },
            this);

        this.on('submit', function() {
            var value = this.radio.getValue().getRawValue();

            if (value == this.loadedValue) {
                this.fireEvent('formsubmitted');
                return;
            }

            var dsid = this.dsid;

            // this should never happen, but lets double check so we
            // do not attempt to write some random crap into the klemme
            if ((value !== dSS.config.deviceParams.OUTPUT_MODE_SWITCH.toString()) &&
                (value !== dSS.config.deviceParams.OUTPUT_MODE_DISABLED.toString()) &&
                (value !== dSS.config.deviceParams.OUTPUT_MODE_DIMMER.toString())) {
                Ext.Msg.alert(dSS._("Error"), dSS._("Attempted to set invalid value") +
                    ": " + value);
                this.fireEvent('formsubmitted');
                return;
            }

            dSS.util.genericRequest({
                    url: '/json/device/setConfig',
                    params:
                    {
                        'class' : 3,
                        index : 0,
                        dsid : this.dsid,
                        value : value
                    },
                    failureMsg: dSS._("Could not save output mode settings"),
                    scope: this,
                    evt: 'formsubmitted'
                },
                function(success) {
                    if (success === true) {
                        var devStore = dSS.data.Loader.getDeviceStore();
                        var record = devStore.getById(dsid);
                        if (record !== undefined) {
                            record.set('outputMode', parseInt(value, 10));
                            record.commit();
                        }
                    }
                }
            );
        },
        this);
    }
});

Ext.reg('dssdevoutputmodeform', dSS.devprops.OutputModeForm);

